@@ -38,21 +38,6 @@
 G_BEGIN_DECLS
 
 #define WEBKIT_TYPE_SETTINGS            (webkit_settings_get_type())
-#define WEBKIT_SETTINGS(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), WEBKIT_TYPE_SETTINGS, WebKitSettings))
-#define WEBKIT_SETTINGS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  WEBKIT_TYPE_SETTINGS, WebKitSettingsClass))
-#define WEBKIT_IS_SETTINGS(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), WEBKIT_TYPE_SETTINGS))
-#define WEBKIT_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  WEBKIT_TYPE_SETTINGS))
-#define WEBKIT_SETTINGS_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  WEBKIT_TYPE_SETTINGS, WebKitSettingsClass))
-
-struct _WebKitSettingsClass {
-    GObjectClass parent_class;
-
-    /*< private >*/
-    void (*_webkit_reserved0) (void);
-    void (*_webkit_reserved1) (void);
-    void (*_webkit_reserved2) (void);
-    void (*_webkit_reserved3) (void);
-};
 
 WEBKIT_DECLARE_FINAL_TYPE (WebKitSettings, webkit_settings, WEBKIT, SETTINGS, GObject)
 
@@ -78,17 +63,17 @@ WEBKIT_API void
 webkit_settings_set_auto_load_images                           (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_API gboolean
+WEBKIT_DEPRECATED gboolean
 webkit_settings_get_load_icons_ignoring_image_load_setting     (WebKitSettings *settings);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_settings_set_load_icons_ignoring_image_load_setting     (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_API gboolean
+WEBKIT_DEPRECATED gboolean
 webkit_settings_get_enable_offline_web_application_cache       (WebKitSettings *settings);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_settings_set_enable_offline_web_application_cache       (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
@@ -105,33 +90,6 @@ webkit_settings_get_enable_html5_database                      (WebKitSettings *
 WEBKIT_API void
 webkit_settings_set_enable_html5_database                      (WebKitSettings *settings,
                                                                 gboolean        enabled);
-WEBKIT_DEPRECATED gboolean
-webkit_settings_get_enable_xss_auditor                         (WebKitSettings *settings);
-
-WEBKIT_DEPRECATED void
-webkit_settings_set_enable_xss_auditor                         (WebKitSettings *settings,
-                                                                gboolean        enabled);
-
-WEBKIT_DEPRECATED gboolean
-webkit_settings_get_enable_frame_flattening                    (WebKitSettings *settings);
-
-WEBKIT_DEPRECATED void
-webkit_settings_set_enable_frame_flattening                    (WebKitSettings *settings,
-                                                                gboolean        enabled);
-
-WEBKIT_DEPRECATED gboolean
-webkit_settings_get_enable_plugins                             (WebKitSettings *settings);
-
-WEBKIT_DEPRECATED void
-webkit_settings_set_enable_plugins                             (WebKitSettings *settings,
-                                                                gboolean        enabled);
-
-WEBKIT_DEPRECATED gboolean
-webkit_settings_get_enable_java                                (WebKitSettings *settings);
-
-WEBKIT_DEPRECATED void
-webkit_settings_set_enable_java                                (WebKitSettings *settings,
-                                                                gboolean        enabled);
 
 WEBKIT_API gboolean
 webkit_settings_get_javascript_can_open_windows_automatically  (WebKitSettings *settings);
@@ -361,12 +319,6 @@ WEBKIT_API void
 webkit_settings_set_enable_smooth_scrolling                    (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_DEPRECATED gboolean
-webkit_settings_get_enable_accelerated_2d_canvas               (WebKitSettings *settings);
-
-WEBKIT_DEPRECATED void
-webkit_settings_set_enable_accelerated_2d_canvas               (WebKitSettings *settings,
-                                                                gboolean        enabled);
 
 WEBKIT_API gboolean
 webkit_settings_get_enable_write_console_messages_to_stdout    (WebKitSettings *settings);
@@ -473,6 +425,28 @@ webkit_settings_get_disable_web_security                       (WebKitSettings *
 WEBKIT_API void
 webkit_settings_set_disable_web_security                       (WebKitSettings *settings,
                                                                 gboolean        disabled);
+
+typedef struct _WebKitFeature WebKitFeature;
+typedef struct _WebKitFeatureList WebKitFeatureList;
+
+WEBKIT_API void
+webkit_settings_set_feature_enabled                            (WebKitSettings *settings,
+                                                                WebKitFeature  *feature,
+                                                                gboolean        enabled);
+
+WEBKIT_API gboolean
+webkit_settings_get_feature_enabled                            (WebKitSettings *settings,
+                                                                WebKitFeature  *feature);
+
+WEBKIT_API WebKitFeatureList *
+webkit_settings_get_all_features                               (void);
+
+WEBKIT_API WebKitFeatureList *
+webkit_settings_get_experimental_features                      (void);
+
+WEBKIT_API WebKitFeatureList *
+webkit_settings_get_development_features                       (void);
+
 G_END_DECLS
 
 #endif /* WebKitSettings_h */
